@@ -1,14 +1,12 @@
 from datetime import datetime, timedelta
 from os import environ
 
+from jose import jwt
 from passlib.context import CryptContext
 
 from fast_auth.models import User
-from jose import jwt
 
-# SECRET_KEY = environ['SECRET_KEY']
-# TTL = int(environ.get('TTL_JWT', default=1440))
-# ALGORITHM = 'HS256'
+ALGORITHM = 'HS256'
 
 pwd_context = CryptContext(schemes=['bcrypt'])
 
@@ -18,7 +16,7 @@ def create_token_jwt(user: User, extra_fields={}):
     data = {
         'exp': datetime.utcnow() + timedelta(minutes=ttl),
         'id': user.id,
-        'name': user.username
+        'name': user.username,
     }
 
     data.update(extra_fields)
