@@ -1,5 +1,13 @@
 from typing import Any
-from sqlalchemy import Column, FetchedValue, ForeignKey, Integer, Text, DateTime
+
+from sqlalchemy import (
+    Column,
+    DateTime,
+    FetchedValue,
+    ForeignKey,
+    Integer,
+    Text,
+)
 from sqlalchemy.orm import declarative_base
 from sqlalchemy.sql.sqltypes import Boolean
 
@@ -10,8 +18,12 @@ class User(Base):
 
     __tablename__ = 'auth_users'
 
-    id = Column(Integer, primary_key=True, autoincrement=True,
-                server_default=FetchedValue())
+    id = Column(
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        server_default=FetchedValue(),
+    )
     username = Column(Text, unique=True)
     email = Column(Text)
     name = Column(Text)
@@ -33,8 +45,12 @@ class Group(Base):
 
     __tablename__ = 'auth_groups'
 
-    id = Column(Integer, primary_key=True, autoincrement=True,
-                server_default=FetchedValue())
+    id = Column(
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        server_default=FetchedValue(),
+    )
     name = Column(Text)
 
 
@@ -42,7 +58,11 @@ class UserGroup(Base):
 
     __tablename__ = 'auth_users_groups'
 
-    id = Column(Integer, primary_key=True, autoincrement=True,
-                server_default=FetchedValue())
+    id = Column(
+        Integer,
+        primary_key=True,
+        autoincrement=True,
+        server_default=FetchedValue(),
+    )
     auth_user_id = Column(Integer, ForeignKey('auth_users.id'))
     auth_group_id = Column(Integer, ForeignKey('auth_groups.id'))
